\name{max.depth.line}
\alias{distribution.max.depth.line}
\alias{distribution.MAD.line}
\alias{distribution.MAD}
\alias{sample.max.depth.line}
\alias{sample.MAD.line}
\alias{add.max.depth.MAD.lines}

\title{Lines with maximum depth and MAD depending on the location}
\description{
  Calculates and plots 
  lines of scale parameters with maximum depth for  given location parameters
  and the lines of MAD with respect to given location parameters
  for distributions (populations)  and samples (data sets).
}

\usage{

distribution.max.depth.line(qdist=function(x){qnorm(x,0,1)}, pdist=function(x){pnorm(x,0,1)},mu.min,mu.max,
        lengthmu=50,d.min=0.05,lengthbeta=100,iter=50,eps=0.0001)

distribution.MAD(qdist=function(x){qnorm(x)}, pdist=function(x){pnorm(x)},mu=qdist(0.5),sym=F, 
       iter=100,eps=0.00000001)

distribution.MAD.line(qdist=function(x){qnorm(x)}, pdist=function(x){pnorm(x)},mu.min,mu.max,
       lengthmu=100,sym=F, iter=100,eps=0.00000001)

sample.max.depth.line(y,mu.min,mu.max,mu.values=T,lengthmu=100,iter=100,eps=0.0000001)

sample.MAD.line(y,mu.min,mu.max,mu.values=T,lengthmu=100)

add.max.depth.MAD.lines(max.depth.line=NULL,MAD.line=NULL)

 }

\arguments{
  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{mu}{location parameter from which the MAD is calculated, default is the median.}
  \item{y}{numerical vector of observations (data set)}
  \item{mu.min}{minimum value for the location parameters.}
  \item{mu.max}{maximum value for the location parameters.}
  \item{mu.values}{logical value where \code{mu.min} and \code{mu.max} are calculated
        from the data set if \code{mu.values=T} (default) otherwise the values must be set.}
  \item{lengthmu}{length of the vector of location parameters for which upper and 
              lower bounds of the contour are calculated. The larger \code{lengthmu} is the 
                 smoother the line is.}
  \item{d.min}{a value which is known to be smaller than the maximum depth for all used locations.} 
  \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter and depth. The larger \code{lengthbeta} 
                   the more  precise are the bounds.}
  \item{iter}{number of iterations for each location parameter.}
  \item{eps}{precision of scale with maximum depth for a given location parameter.}
  \item{sym}{ if \code{sym=T}, then it is a symmetric distribution and mu is assumed to be the
           median.}
  \item{max.depth.line}{a list given by \code{distribution.max.depth.line} or 
          \code{sample.max.depth.line}. This list must have components \code{mu} and \code{s.mu} 
          where each components consist of a vector of same length. If \code{max.depth.line=NULL}, 
          (default) then the maximum depth line is not plotted.}
  \item{MAD.line}{a list given by \code{distribution.MAD.line} or 
          \code{sample.MAD.line}. This list must have components \code{mu} and \code{MAD} 
          where each components consist of a vector of same length. If \code{MAD=NULL}, 
          (default) then the maximum depth line is not plotted.}
}

\details{

  \code{distribution.max.depth.line} calculates scale parameters with maximum depth for
        several locations parameters for distributions.
 
 \code{distribution.MAD} calculates the median of absolute deviations from a given location 
        parameter for distributions.
 
  \code{distribution.MAD.line} calculates the median of absolute deviations from several location 
        parameters for distributions.
 
  \code{sample.max.depth.line} calculates scale parameters with maximum depth for
        several locations parameters for samples (data sets).
 
  \code{distribution.MAD.line} calculates the median of absolute deviations from several location 
        parameters for samples (data sets).
 
 The number of used locations parameters is given  by \code{lengthmu} and the location 
       parameters are lying equispaced in the interval from  \code{mu.min} to \code{mu.max}.

 \code{add.max.depth.MAD.lines} adds the lines given by \code{distribution.max.depth.line},
        \code{distribution.MAD.line}  or \code{sample.max.depth.line},  \code{distribution.MAD.line} 
        to an existing contour plot.
}

\value{
  Return value of  \code{distribution.max.depth.line}  and \code{sample.max.depth.line}  is
  a list with the following components:
       \code{mu} a vector of location parameters, 
       \code{s.mu} a vector with corresponding scale parameters with maximum depth.
  
  Return value of  \code{distribution.MAD.line}  and \code{sample.MAD.line}  is
  a list with the following components:
       \code{mu} a vector of location parameters, 
       \code{MAD} a vector with corresponding MAD's.

  \code{add.max.depth.MAD.lines} has no return value.
}

\seealso{\code{\link{distribution.depth.contours}}, \code{\link{sample.depth.contours}}, 
            \code{\link{distribution.max.depth}},  \code{\link{sample.max.depth}}}

\examples{

 normal.depth.contours<-distribution.depth.contours(lengthmu=1000)
 plot.depth.contours(normal.depth.contours)
 normal.max.depth.line<-distribution.max.depth.line(mu.min=-1.5,mu.max=1.5,lengthmu=100)
 normal.MAD.line<-distribution.MAD.line(mu.min=-1.5,mu.max=1.5,lengthmu=100)
 add.max.depth.MAD.lines(normal.max.depth.line)
 add.max.depth.MAD.lines(MAD.line=normal.MAD.line)

 y<-rt(100,1)
 y.depth.contours<-sample.depth.contours(y=y,lengthmu=1000)
 plot.depth.contours(y.depth.contours)
 y.max.depth.line<-sample.max.depth.line(y=y)
 y.MAD.line<-sample.MAD.line(y=y)
 add.max.depth.MAD.lines(y.max.depth.line,y.MAD.line)

 }

\references{
 Mizera, I. and Mller, C.H. (2003). Location-scale depth.
 }


\author{
  Christine Mller (mueller@math.uni-oldenburg.de)
  }


\keyword{ Student depth }
\keyword{ location-scale }
\keyword{ maximum depth for given location }
\keyword{ MAD }


