\name{max.depth}
\alias{distribution.max.depth}
\alias{sample.max.depth}
\title{Maximum Depth}
\description{
  
  Calculates the maximum location-scale depth and 
  the location-scale parameter with maximum depth
  
}

\usage{

  distribution.max.depth(qdist=function(x){qnorm(x,0,1)}, pdist=function(x){pnorm(x,0,1)},
           d.min=1/3,lengthbeta=100,iter=10,eps=0.001)

  sample.max.depth(y,iter=100,eps=0.0001,p.length=10)

}

\arguments{

  \item{qdist}{quantile function of the distribution, default is the quantile function 
                     of the standard normal distribution.}
  \item{pdist}{distribution function of the distribution, default is the distribution function
                     of the standard normal distribution.}
  \item{y}{numerical vector of observations (data set)}
  \item{d.min}{a value which is known to be smaller than the maximum depth.}
  \item{lengthbeta}{length of the vector for calculating the upper and lower bound for the
                   contour for a given location parameter. The larger \code{lengthbeta} the more 
                      precise are the bounds.}
 \item{iter}{number of iterations.}
 \item{eps}{precision of location and scale with maximum depth.}
 \item{p.length}{maximum number of interations in a final precision step.}

}
\details{
  
  \code{distribution.max.depth} calculates the maximum depth and 
          the parameter pair of location and scale with maximum depth
          for a distribution (population).
  \code{sample.max.depth} calculates the maximum depth and the maximum
          depth estimator for location and scale for a sample (data set).  
 
}
\value{
  Both functions return a vector with the following components:
     \code{"max.depth"} is  the maximum depth, a value in (0,1) for distributions
            and an integer smaller than the sample size for samples
     \code{"mu"} is the location with maximum depth,
     \code{"sigma"} is the scale with maximum depth.
}


\seealso{\code{\link{distribution.depth.contours}}, \code{\link{sample.depth.contours}}, 
            \code{\link{distribution.max.depth.line}},  \code{\link{sample.max.depth.line}}}

\examples{
 
 distribution.max.depth(qdist=function(x){qt(x,1)},pdist=function(x){pt(x,1)},iter=50)

  y<-rt(100,1)
  sample.max.depth(y=y,iter=50)
  
}

\references{
   Mizera, I. and Mller, C.H. (2003). Location-scale depth.
}
\author{ Christine Mller, mueller@math.uni-oldenburg.de }


\keyword{ Student depth }
\keyword{ location-scale }
\keyword{ maximum depth }
\keyword{ maximum depth estimator }
